summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--gui/packages/desktop/src/renderer/app.js7
1 files changed, 5 insertions, 2 deletions
diff --git a/gui/packages/desktop/src/renderer/app.js b/gui/packages/desktop/src/renderer/app.js
index b693a84544..d62745ee97 100644
--- a/gui/packages/desktop/src/renderer/app.js
+++ b/gui/packages/desktop/src/renderer/app.js
@@ -469,6 +469,7 @@ export default class AppRenderer {
async _onCloseConnection(error: ?Error) {
const actions = this._reduxActions;
+ const history = this._memoryHistory;
// save to redux that the app disconnected from daemon
actions.daemon.disconnected();
@@ -489,8 +490,10 @@ export default class AppRenderer {
recover();
});
- // take user back to the launch screen `/`.
- actions.history.replace('/');
+ // take user back to the launch screen `/` except when user is in settings.
+ if (!history.location.pathname.startsWith('/settings')) {
+ actions.history.replace('/');
+ }
}
}